$! Compile and link Xstar under OpenVMS 
$!
$! In case of problems with the install you might contact me at
$! zinser@decus.de (preferred) or zinser@sysdev.deutsche-boerse.de
$!
$!------------------------------------------------------------------------------
$!
$! Define some general constants
$!
$ true    = 1
$ false   = 0
$ tmpnam  = "TEMP" + f$getjpi("","PID") + ".TXT"
$ version = "Xstar"
$ srcs    = "animate,check_bounce,collide,default_init,dump_sys,global_vars," +-
            "init_colors,init_stars,init_sys_1a,init_sys_1b,init_sys_1c," +-
	    "init_sys_4,init_sys_8,init_sys_8b,move_stars_ab4," +-
	    "move_stars_ab7,move_stars_am7,move_stars_euler1," +-
	    "move_stars_gpemce8,move_stars_rk4,move_stars_rk4b," +-
	    "move_stars_taylor3,plot_collapsars,reset_hstep,set_star_disp," +-
	    "set_sys_param,set_xmva,sys_const,update_screen,xstar"
$!
$! Get compiler info
$!
$ CFLAGS = "/OPTIMIZE/define=(NEEDS_TYPEDEFS)"
$ decc = f$search("SYS$SYSTEM:DECC$COMPILER.EXE") .nes. "" -
        .and. CFLAGS - "/VAXC" .eqs. CFLAGS
$ all_cflags = CFLAGS
$ if decc then all_cflags = "/DECC/PREFIX=ALL " + all_cflags
$!
$! Check current Xstar version
$!
$ if f$search("patchlevel.h").nes. ""
$ then
$   search/out='tmpnam' patchlevel.h "define VERSION"
$   if ($status .eqs. "%X00000001")
$   then
$     open/read inp 'tmpnam'
$     read inp line
$     version = version + f$element(0,",",f$element(1,"""",line))
$     close inp
$   endif
$   if f$search("''tmpnam'").nes."" then delete/noconfirm 'tmpnam';*
$ endif
$!
$!      Build the option-file
$!
$ open/write optf xstar.opt
$ num = 0
$OPTF_LOOP:
$ module = f$element(num,",",srcs)
$ if module .eqs. "," then goto FIN_OPTF
$ write optf "''module'.obj"
$ num = num + 1
$ goto optf_loop
$FIN_OPTF:
$ write optf "Identification=""''VERSION'"""
$!
$ write optf "sys$share:decw$xlibshr.exe/share"
$ if .not.decc then write optf "SYS$SHARE:VAXCRTL/SHARE"
$ close optf
$!
$! Actually build the program
$!
$ write sys$output "Compiling Xstar "
$ num = 0
$CC_LOOP:
$ module = f$element(num,",",srcs)
$ if module .eqs. "," then goto lnk
$ call make 'module'.obj "cc ''all_cflags' ''module'" 'module'.c 
$ num = num + 1
$ goto cc_loop
$LNK:
$ write sys$output "Linking Xstar"
$ on error then goto ERR
$ call make xstar.exe "link xstar.opt/opt" *.obj
$ write sys$output "Xstar build completed."
$ exit
$ !
$ ERR:
$  write sys$output ""
$  write sys$output "An error occured while linking Xstar - Sorry"
$ EXIT
$!
$MAKE: SUBROUTINE   !SUBROUTINE TO CHECK DEPENDENCIES
$ V = 'F$Verify(0)
$! P1 = What we are trying to make
$! P2 = Command to make it
$! P3 - P8  What it depends on
$
$ If F$Search(P1) .Eqs. "" Then Goto Makeit
$ Time = F$CvTime(F$File(P1,"RDT"))
$arg=3
$Loop:
$       Argument = P'arg
$       If Argument .Eqs. "" Then Goto Exit
$       El=0
$Loop2:
$       File = F$Element(El," ",Argument)
$       If File .Eqs. " " Then Goto Endl
$       AFile = ""
$Loop3:
$       OFile = AFile
$       AFile = F$Search(File)
$       If AFile .Eqs. "" .Or. AFile .Eqs. OFile Then Goto NextEl
$       If F$CvTime(F$File(AFile,"RDT")) .Ges. Time Then Goto Makeit
$       Goto Loop3
$NextEL:
$       El = El + 1
$       Goto Loop2
$EndL:
$ arg=arg+1
$ If arg .Le. 8 Then Goto Loop
$ Goto Exit
$
$Makeit:
$ VV=F$VERIFY(0)
$ write sys$output P2
$ 'P2
$ VV='F$Verify(VV)
$Exit:
$ If V Then Set Verify
$ENDSUBROUTINE
